@@ -14,7 +14,9 @@
 * Copied from the survival package by Terry Therneau, version 2.35-7
 */
 
-void chsolve2(double **matrix, int n, double *y)
+#include <R_ext/Visibility.h>
+
+void attribute_hidden chsolve2(double **matrix, int n, double *y)
      {
      register int i,j;
      register double temp;
